Learn R Programming

doBy (version 4.5-11)

haldCement: Heat development in cement under hardening.

Description

Heat development in cement under hardening related to the chemical composition.

Usage

data(haldCement)

Arguments

References

Anders Hald (1949); Statistiske Metoder; Akademisk Forlag (in Danish), page 509.

Examples

Run this code
data(haldCement)

if( interactive() ){
pairs( haldCement )
}
m <- lm( y~x1+x2+x3+x4, data=haldCement )
summary( m )

# Notice: The model explains practically all variation in data;
# yet none of the explanatory variables appear to be statistically
# significant...

Run the code above in your browser using DataLab